require 'puppet/face'
require 'puppet/cloudpack/vmware'

Puppet::Face.define(:node_vmware, '0.0.1') do
  action :find do
    summary "Find a VMware Virtual Machine"
    description <<-'EOT'
      Find a single VMware Virtual Machine by path. The default output of
      the find action provides a limited set of information.  To obtain all
      available attributes for a virtual machine, please use a different
      rendering mode such as --render-as yaml.
    EOT

    returns 'Array of VirtualMachine attribute hashes.'

    examples <<-'EOT'
      $ puppet node_vmware find
      /Datacenters/Solutions/vm/el56
        powerstate: poweredOff
        name:       el56
        hostname:   --------
        instanceid: 50323f93-6835-1178-8b8f-9e2109890e1a
        ipaddress:  ---.---.---.---
        template:   true
    EOT

    arguments "<path>"

    Puppet::CloudPack::VMware.add_timeout_option(self)

    when_invoked do |path, options|
      options[:path] = path
      Puppet::CloudPack::VMware.find(options)
    end

    when_rendering :console do |return_value|
      Puppet.notice "Complete"
      return_value.map do |vm|
        "#{vm[:path]}/#{vm[:name]}\n" <<
        "  powerstate: #{vm[:power_state]}\n" <<
        "  name:       #{vm[:name]}\n" <<
        "  hostname:   #{vm[:hostname] || '--------'}\n" <<
        "  instanceid: #{vm[:instance_uuid]}\n" <<
        "  ipaddress:  #{vm[:ipaddress] || '---.---.---.---'}\n" <<
        "  template:   #{vm[:is_a_template]}\n"
      end.join("\n")
    end
  end
end
